pub struct ShippingServiceOptions {
    pub delivery_experience: DeliveryExperienceType,
    pub declared_value: Option<Box<CurrencyAmount>>,
    pub carrier_will_pick_up: bool,
    pub carrier_will_pick_up_option: Option<CarrierWillPickUpOption>,
    pub label_format: Option<LabelFormat>,
}
ShippingServiceOptions : Extra services provided by a carrier.

Fields

delivery_experience: DeliveryExperienceTypedeclared_value: Option<Box<CurrencyAmount>>carrier_will_pick_up: bool

When true, the carrier will pick up the package. Note: Scheduled carrier pickup is available only using Dynamex (US), DPD (UK), and Royal Mail (UK).

carrier_will_pick_up_option: Option<CarrierWillPickUpOption>label_format: Option<LabelFormat>

Implementations

Extra services provided by a carrier.