Struct amazon_sp_merchant_fulfillment::models::shipping_service_options::ShippingServiceOptions
source · [−]pub struct ShippingServiceOptions {
pub delivery_experience: DeliveryExperienceType,
pub declared_value: Option<Box<CurrencyAmount>>,
pub carrier_will_pick_up: bool,
pub carrier_will_pick_up_option: Option<CarrierWillPickUpOption>,
pub label_format: Option<LabelFormat>,
}Expand description
ShippingServiceOptions : Extra services provided by a carrier.
Fields
delivery_experience: DeliveryExperienceTypedeclared_value: Option<Box<CurrencyAmount>>carrier_will_pick_up: boolWhen true, the carrier will pick up the package. Note: Scheduled carrier pickup is available only using Dynamex (US), DPD (UK), and Royal Mail (UK).
carrier_will_pick_up_option: Option<CarrierWillPickUpOption>label_format: Option<LabelFormat>Implementations
sourceimpl ShippingServiceOptions
impl ShippingServiceOptions
sourcepub fn new(
delivery_experience: DeliveryExperienceType,
carrier_will_pick_up: bool
) -> ShippingServiceOptions
pub fn new(
delivery_experience: DeliveryExperienceType,
carrier_will_pick_up: bool
) -> ShippingServiceOptions
Extra services provided by a carrier.